You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@carbondata.apache.org by gv...@apache.org on 2018/03/09 06:37:52 UTC

carbondata git commit: [CARBONDATA-1993] Carbon properties default values fix and corresponding template and document correction

Repository: carbondata
Updated Branches:
  refs/heads/master 39fa1eb58 -> be600bc90


[CARBONDATA-1993] Carbon properties default values fix and corresponding template and document correction

This closes #1831


Project: http://git-wip-us.apache.org/repos/asf/carbondata/repo
Commit: http://git-wip-us.apache.org/repos/asf/carbondata/commit/be600bc9
Tree: http://git-wip-us.apache.org/repos/asf/carbondata/tree/be600bc9
Diff: http://git-wip-us.apache.org/repos/asf/carbondata/diff/be600bc9

Branch: refs/heads/master
Commit: be600bc907dbd6051b7ef51452c7a4fe044f4786
Parents: 39fa1eb
Author: mohammadshahidkhan <mo...@gmail.com>
Authored: Thu Jan 18 16:54:15 2018 +0530
Committer: Venkata Ramana G <ra...@huawei.com>
Committed: Fri Mar 9 12:07:35 2018 +0530

----------------------------------------------------------------------
 conf/carbon.properties.template                 | 32 ++++-------
 .../core/constants/CarbonCommonConstants.java   | 56 +++-----------------
 .../core/datastore/page/ColumnPage.java         |  4 +-
 docs/configuration-parameters.md                | 19 +++----
 docs/installation-guide.md                      |  6 +--
 .../carbondata/examples/CompareTest.scala       |  2 +-
 .../carbondata/examples/ConcurrencyTest.scala   |  2 +-
 .../carbondata/examples/ExampleUtils.scala      |  2 +-
 .../hadoop/test/util/StoreCreator.java          |  1 -
 .../presto/util/CarbonDataStoreCreator.scala    |  4 +-
 .../sdv/generated/OffheapQuery1TestCase.scala   |  2 -
 .../sdv/generated/OffheapQuery2TestCase.scala   |  2 -
 .../aggquery/IntegerDataTypeTestCase.scala      |  6 +--
 .../TestNullAndEmptyFieldsUnsafe.scala          |  6 +--
 .../TestLoadDataWithHiveSyntaxUnsafe.scala      |  6 +--
 .../spark/rdd/NewCarbonDataLoadRDD.scala        |  1 -
 .../CarbonAlterTableCompactionCommand.scala     |  4 +-
 .../sql/test/Spark2TestQueryExecutor.scala      |  2 -
 .../BooleanDataTypesBigFileTest.scala           |  4 +-
 .../booleantype/BooleanDataTypesLoadTest.scala  |  4 +-
 .../carbondata/processing/StoreCreator.java     |  1 -
 21 files changed, 47 insertions(+), 119 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/conf/carbon.properties.template
----------------------------------------------------------------------
diff --git a/conf/carbon.properties.template b/conf/carbon.properties.template
index 8c1e458..9727578 100644
--- a/conf/carbon.properties.template
+++ b/conf/carbon.properties.template
@@ -17,29 +17,26 @@
 #
 
 #################### System Configuration ##################
-#Mandatory. Carbon Store path
-carbon.storelocation=hdfs://hacluster/Opt/CarbonStore
+##Optional. Location where CarbonData will create the store, and write the data in its own format.
+##If not specified then it takes spark.sql.warehouse.dir path.
+#carbon.storelocation
 #Base directory for Data files
-carbon.ddl.base.hdfs.url=hdfs://hacluster/opt/data
+#carbon.ddl.base.hdfs.url
 #Path where the bad records are stored
-carbon.badRecords.location=/opt/Carbon/Spark/badrecords
+#carbon.badRecords.location
 
 #################### Performance Configuration ##################
 ######## DataLoading Configuration ########
 #File read buffer size used during sorting(in MB) :MIN=1:MAX=100
-carbon.sort.file.buffer.size=20
-#Rowset size exchanged between data load graph steps :MIN=500:MAX=1000000
-carbon.graph.rowset.size=100000
+carbon.sort.file.buffer.size=10
 #Number of cores to be used while data loading
-carbon.number.of.cores.while.loading=6
+carbon.number.of.cores.while.loading=2
 #Record count to sort and write to temp intermediate files
-carbon.sort.size=500000
+carbon.sort.size=100000
 #Algorithm for hashmap for hashkey calculation
 carbon.enableXXHash=true
 #Number of cores to be used for block sort while dataloading
 #carbon.number.of.cores.block.sort=7
-#max level cache size upto which level cache will be loaded in memory
-#carbon.max.level.cache.size=-1
 #enable prefetch of data during merge sort while reading data from sort temp files in data loading
 #carbon.merge.sort.prefetch=true
 ######## Alter Partition Configuration ########
@@ -76,22 +73,15 @@ carbon.enable.quick.filter=false
 #carbon.block.meta.size.reserved.percentage=10
 ##csv reading buffer size.
 #carbon.csv.read.buffersize.byte=1048576
-##To identify and apply compression for non-high cardinality columns
-#high.cardinality.value=100000
 ##maximum no of threads used for reading intermediate files for final merging.
 #carbon.merge.sort.reader.thread=3
 ##Carbon blocklet size. Note: this configuration cannot be change once store is generated
 #carbon.blocklet.size=120000
-##number of retries to get the metadata lock for loading data to table
-#carbon.load.metadata.lock.retries=3
 ##Minimum blocklets needed for distribution.
 #carbon.blockletdistribution.min.blocklet.size=10
 ##Interval between the retries to get the lock
 #carbon.load.metadata.lock.retry.timeout.sec=5
-##Temporary store location, By default it will take System.getProperty("java.io.tmpdir")
-#carbon.tempstore.location=/opt/Carbon/TempStoreLoc
-##data loading records count logger
-#carbon.load.log.counter=500000
+
 ##To dissable/enable carbon block distribution
 #carbon.custom.block.distribution=false
 ######## Compaction Configuration ########
@@ -107,10 +97,8 @@ carbon.enable.quick.filter=false
 ##Min max is feature added to enhance query performance. To disable this feature, make it false.
 #carbon.enableMinMax=true
 ######## Global Dictionary Configurations ########
-##Percentage to identify whether column cardinality is more than configured percent of total row count
-#high.cardinality.row.count.percentage=80
 ##The property to set the date to be considered as start date for calculating the timestamp.
-#carbon.cutOffTimestamp=2000-01-01 00:00:00
+#carbon.cutOffTimestamp
 ##The property to set the timestamp (ie milis) conversion to the SECOND, MINUTE, HOUR or DAY level.
 #carbon.timegranularity=SECOND
 ##the number of prefetched rows in sort step

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/core/src/main/java/org/apache/carbondata/core/constants/CarbonCommonConstants.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/carbondata/core/datastore/page/ColumnPage.java b/core/src/main/java/org/apache/carbondata/core/datastore/page/ColumnPage.java
index 58627d0..ebca3b7 100644
--- a/core/src/main/java/org/apache/carbondata/core/datastore/page/ColumnPage.java
+++ b/core/src/main/java/org/apache/carbondata/core/datastore/page/ColumnPage.java
@@ -61,8 +61,8 @@ public abstract class ColumnPage {
   private ColumnPageStatsCollector statsCollector;
 
   protected static final boolean unsafe = Boolean.parseBoolean(CarbonProperties.getInstance()
-      .getProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING,
-          CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING_DEFAULT));
+      .getProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE,
+          CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_DEFAULT));
 
   /**
    * Create a new column page with input data type and page size.

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/docs/configuration-parameters.md
----------------------------------------------------------------------
diff --git a/docs/configuration-parameters.md b/docs/configuration-parameters.md
index 7221420..4a66f2e 100644
--- a/docs/configuration-parameters.md
+++ b/docs/configuration-parameters.md
@@ -32,10 +32,10 @@ This section provides the details of all the configurations required for the Car
 
 | Property | Default Value | Description |
 |----------------------------|-------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
-| carbon.storelocation | /user/hive/warehouse/carbon.store | Location where CarbonData will create the store, and write the data in its own format. NOTE: Store location should be in HDFS. |
-| carbon.ddl.base.hdfs.url | hdfs://hacluster/opt/data | This property is used to configure the HDFS relative path, the path configured in carbon.ddl.base.hdfs.url will be appended to the HDFS path configured in fs.defaultFS. If this path is configured, then user need not pass the complete path while dataload. For example: If absolute path of the csv file is hdfs://10.18.101.155:54310/data/cnbc/2016/xyz.csv, the path "hdfs://10.18.101.155:54310" will come from property fs.defaultFS and user can configure the /data/cnbc/ as carbon.ddl.base.hdfs.url. Now while dataload user can specify the csv path as /2016/xyz.csv. |
-| carbon.badRecords.location | /opt/Carbon/Spark/badrecords | Path where the bad records are stored. |
-| carbon.data.file.version | 3 | If this parameter value is set to 1, then CarbonData will support the data load which is in old format(0.x version). If the value is set to 2(1.x onwards version), then CarbonData will support the data load of new format only. The default value for this parameter is 3(latest version is set as default version). It improves the query performance by ~20% to 50%. For configuring V3 format explicitly, add carbon.data.file.version = V3 in carbon.properties file. |
+| carbon.storelocation |  | Location where CarbonData will create the store, and write the data in its own format. If not specified then it takes spark.sql.warehouse.dir path. NOTE: Store location should be in HDFS. |
+| carbon.ddl.base.hdfs.url |  | This property is used to configure the HDFS relative path, the path configured in carbon.ddl.base.hdfs.url will be appended to the HDFS path configured in fs.defaultFS. If this path is configured, then user need not pass the complete path while dataload. For example: If absolute path of the csv file is hdfs://10.18.101.155:54310/data/cnbc/2016/xyz.csv, the path "hdfs://10.18.101.155:54310" will come from property fs.defaultFS and user can configure the /data/cnbc/ as carbon.ddl.base.hdfs.url. Now while dataload user can specify the csv path as /2016/xyz.csv. |
+| carbon.badRecords.location |  | Path where the bad records are stored. |
+| carbon.data.file.version | V3 | If this parameter value is set to 1, then CarbonData will support the data load which is in old format(0.x version). If the value is set to 2(1.x onwards version), then CarbonData will support the data load of new format only.|
 | carbon.streaming.auto.handoff.enabled | true | If this parameter value is set to true, auto trigger handoff function will be enabled.|
 | carbon.streaming.segment.max.size | 1024000000 | This parameter defines the maximum size of the streaming segment. Setting this parameter to appropriate value will avoid impacting the streaming ingestion. The value is in bytes.|
 
@@ -48,8 +48,8 @@ This section provides the details of all the configurations required for CarbonD
 
 | Parameter | Default Value | Description | Range |
 |--------------------------------------|---------------|----------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
-| carbon.number.of.cores.while.loading | 6 | Number of cores to be used while loading data. |  |
-| carbon.sort.size | 500000 | Record count to sort and write intermediate files to temp. |  |
+| carbon.number.of.cores.while.loading | 2 | Number of cores to be used while loading data. |  |
+| carbon.sort.size | 100000 | Record count to sort and write intermediate files to temp. |  |
 | carbon.max.driver.lru.cache.size | -1 | Max LRU cache size upto which data will be loaded at the driver side. This value is expressed in MB. Default value of -1 means there is no memory limit for caching. Only integer values greater than 0 are accepted. |  |
 | carbon.max.executor.lru.cache.size | -1 | Max LRU cache size upto which data will be loaded at the executor side. This value is expressed in MB. Default value of -1 means there is no memory limit for caching. Only integer values greater than 0 are accepted. If this parameter is not configured, then the carbon.max.driver.lru.cache.size value will be considered. |  |
 | carbon.merge.sort.prefetch | true | Enable prefetch of data during merge sort while reading data from sort temp files in data loading. |  |
@@ -98,19 +98,16 @@ This section provides the details of all the configurations required for CarbonD
   
 | Parameter | Default Value | Description |
 |---------------------------------------------|--------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
-| carbon.sort.file.write.buffer.size | 16777216 | File write buffer size used during sorting (minValue = 10 KB, maxValue=10MB). |
+| carbon.sort.file.write.buffer.size | 16384 | File write buffer size used during sorting. Minimum allowed buffer size is 10240 byte and Maximum allowed buffer size is 10485760 byte. |
 | carbon.lock.type | LOCALLOCK | This configuration specifies the type of lock to be acquired during concurrent operations on table. There are following types of lock implementation: - LOCALLOCK: Lock is created on local file system as file. This lock is useful when only one spark driver (thrift server) runs on a machine and no other CarbonData spark application is launched concurrently. - HDFSLOCK: Lock is created on HDFS file system as file. This lock is useful when multiple CarbonData spark applications are launched and no ZooKeeper is running on cluster and HDFS supports file based locking. |
 | carbon.sort.intermediate.files.limit | 20 | Minimum number of intermediate files after which merged sort can be started (minValue = 2, maxValue=50). |
 | carbon.block.meta.size.reserved.percentage | 10 | Space reserved in percentage for writing block meta data in CarbonData file. |
 | carbon.csv.read.buffersize.byte | 1048576 | csv reading buffer size. |
-| high.cardinality.value | 100000 | To identify and apply compression for non-high cardinality columns. |
 | carbon.merge.sort.reader.thread | 3 | Maximum no of threads used for reading intermediate files for final merging. |
 | carbon.concurrent.lock.retries | 100 | Specifies the maximum number of retries to obtain the lock for concurrent operations. This is used for concurrent loading. |
 | carbon.concurrent.lock.retry.timeout.sec | 1 | Specifies the interval between the retries to obtain the lock for concurrent operations. |
 | carbon.lock.retries | 3 | Specifies the maximum number of retries to obtain the lock for any operations other than load. |
 | carbon.lock.retry.timeout.sec | 5 | Specifies the interval between the retries to obtain the lock for any operation other than load. |
-| carbon.tempstore.location | /opt/Carbon/TempStoreLoc | Temporary store location. By default it takes System.getProperty("java.io.tmpdir"). |
-| carbon.load.log.counter | 500000 | Data loading records count logger. |
 | carbon.skip.empty.line | false | Setting this property ignores the empty lines in the CSV file during the data load |
 | carbon.enable.calculate.size | true | **For Load Operation**: Setting this property calculates the size of the carbon data file (.carbondata) and carbon index file (.carbonindex) for every load and updates the table status file. **For Describe Formatted**: Setting this property calculates the total size of the carbon data files and carbon index files for the respective table and displays in describe formatted command. | 
 
@@ -139,7 +136,7 @@ This section provides the details of all the configurations required for CarbonD
   
 | Parameter | Default Value | Description |
 |---------------------------------------|---------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
-| carbon.cutOffTimestamp | 1970-01-01 05:30:00 | Sets the start date for calculating the timestamp. Java counts the number of milliseconds from start of "1970-01-01 00:00:00". This property is used to customize the start of position. For example "2000-01-01 00:00:00". The date must be in the form "carbon.timestamp.format". |
+| carbon.cutOffTimestamp |  | Sets the start date for calculating the timestamp. Java counts the number of milliseconds from start of "1970-01-01 00:00:00". This property is used to customize the start of position. For example "2000-01-01 00:00:00". The date must be in the form "carbon.timestamp.format". |
 | carbon.timegranularity | SECOND | The property used to set the data granularity level DAY, HOUR, MINUTE, or SECOND. |
   
 ##  Spark Configuration

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/docs/installation-guide.md
----------------------------------------------------------------------
diff --git a/docs/installation-guide.md b/docs/installation-guide.md
index 0c8790b..37f1fdb 100644
--- a/docs/installation-guide.md
+++ b/docs/installation-guide.md
@@ -61,7 +61,7 @@ followed by :
 
 | Property             | Required | Description                                                                            | Example                             | Remark  |
 |----------------------|----------|----------------------------------------------------------------------------------------|-------------------------------------|---------|
-| carbon.storelocation | NO       | Location where data CarbonData will create the store and write the data in its own format. | hdfs://HOSTNAME:PORT/Opt/CarbonStore      | Propose to set HDFS directory |
+| carbon.storelocation | NO       | Location where data CarbonData will create the store and write the data in its own format. If not specified then it takes spark.sql.warehouse.dir path. | hdfs://HOSTNAME:PORT/Opt/CarbonStore      | Propose to set HDFS directory |
 
 
 8. Verify the installation. For example:
@@ -119,7 +119,7 @@ mv carbondata.tar.gz carbonlib/
 
 | Property | Required | Description | Example | Default Value |
 |----------------------|----------|----------------------------------------------------------------------------------------|-------------------------------------|---------------|
-| carbon.storelocation | NO | Location where CarbonData will create the store and write the data in its own format. | hdfs://HOSTNAME:PORT/Opt/CarbonStore | Propose to set HDFS directory|
+| carbon.storelocation | NO | Location where CarbonData will create the store and write the data in its own format. If not specified then it takes spark.sql.warehouse.dir path.| hdfs://HOSTNAME:PORT/Opt/CarbonStore | Propose to set HDFS directory|
 
 6. Verify the installation.
 
@@ -148,7 +148,7 @@ $SPARK_HOME/carbonlib/$CARBON_ASSEMBLY_JAR <carbon_store_path>
 | Parameter | Description | Example |
 |---------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------|
 | CARBON_ASSEMBLY_JAR | CarbonData assembly jar name present in the `$SPARK_HOME/carbonlib/` folder. | carbondata_2.xx-x.x.x-SNAPSHOT-shade-hadoop2.7.2.jar |
-| carbon_store_path | This is a parameter to the CarbonThriftServer class. This a HDFS path where CarbonData files will be kept. Strongly Recommended to put same as carbon.storelocation parameter of carbon.properties. | `hdfs://<host_name>:port/user/hive/warehouse/carbon.store` |
+| carbon_store_path | This is a parameter to the CarbonThriftServer class. This a HDFS path where CarbonData files will be kept. Strongly Recommended to put same as carbon.storelocation parameter of carbon.properties. If not specified then it takes spark.sql.warehouse.dir path. | `hdfs://<host_name>:port/user/hive/warehouse/carbon.store` |
 
 **NOTE**: From Spark 1.6, by default the Thrift server runs in multi-session mode. Which means each JDBC/ODBC connection owns a copy of their own SQL configuration and temporary function registry. Cached tables are still shared though. If you prefer to run the Thrift server in single-session mode and share all SQL configuration and temporary function registry, please set option `spark.sql.hive.thriftServer.singleSession` to `true`. You may either add this option to `spark-defaults.conf`, or pass it to `spark-submit.sh` via `--conf`:
 

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/examples/spark2/src/main/scala/org/apache/carbondata/examples/CompareTest.scala
----------------------------------------------------------------------
diff --git a/examples/spark2/src/main/scala/org/apache/carbondata/examples/CompareTest.scala b/examples/spark2/src/main/scala/org/apache/carbondata/examples/CompareTest.scala
index fe87d7c..64ccca9 100644
--- a/examples/spark2/src/main/scala/org/apache/carbondata/examples/CompareTest.scala
+++ b/examples/spark2/src/main/scala/org/apache/carbondata/examples/CompareTest.scala
@@ -366,7 +366,7 @@ object CompareTest {
         .addProperty("carbon.enable.vector.reader", "true")
         .addProperty("enable.unsafe.sort", "true")
         .addProperty("carbon.blockletgroup.size.in.mb", "32")
-        .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING, "true")
+        .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE, "true")
     import org.apache.spark.sql.CarbonSession._
     val rootPath = new File(this.getClass.getResource("/").getPath
         + "../../../..").getCanonicalPath

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/examples/spark2/src/main/scala/org/apache/carbondata/examples/ConcurrencyTest.scala
----------------------------------------------------------------------
diff --git a/examples/spark2/src/main/scala/org/apache/carbondata/examples/ConcurrencyTest.scala b/examples/spark2/src/main/scala/org/apache/carbondata/examples/ConcurrencyTest.scala
index a0b0e1a..f82fa39 100644
--- a/examples/spark2/src/main/scala/org/apache/carbondata/examples/ConcurrencyTest.scala
+++ b/examples/spark2/src/main/scala/org/apache/carbondata/examples/ConcurrencyTest.scala
@@ -326,7 +326,7 @@ object ConcurrencyTest {
       .addProperty("carbon.enable.vector.reader", "true")
       .addProperty("enable.unsafe.sort", "true")
       .addProperty("carbon.blockletgroup.size.in.mb", "32")
-      .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING, "true")
+      .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE, "true")
     import org.apache.spark.sql.CarbonSession._
     val rootPath = new File(this.getClass.getResource("/").getPath
       + "../../../..").getCanonicalPath

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/examples/spark2/src/main/scala/org/apache/carbondata/examples/ExampleUtils.scala
----------------------------------------------------------------------
diff --git a/examples/spark2/src/main/scala/org/apache/carbondata/examples/ExampleUtils.scala b/examples/spark2/src/main/scala/org/apache/carbondata/examples/ExampleUtils.scala
index fee5e7c..0c725e1 100644
--- a/examples/spark2/src/main/scala/org/apache/carbondata/examples/ExampleUtils.scala
+++ b/examples/spark2/src/main/scala/org/apache/carbondata/examples/ExampleUtils.scala
@@ -42,7 +42,7 @@ object ExampleUtils {
     CarbonProperties.getInstance()
       .addProperty(CarbonCommonConstants.CARBON_TIMESTAMP_FORMAT, "yyyy/MM/dd HH:mm:ss")
       .addProperty(CarbonCommonConstants.CARBON_DATE_FORMAT, "yyyy/MM/dd")
-      .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING, "true")
+      .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE, "true")
       .addProperty(CarbonCommonConstants.CARBON_BADRECORDS_LOC, "")
 
     val masterUrl = if (workThreadNum <= 1) {

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/hadoop/src/test/java/org/apache/carbondata/hadoop/test/util/StoreCreator.java
----------------------------------------------------------------------
diff --git a/hadoop/src/test/java/org/apache/carbondata/hadoop/test/util/StoreCreator.java b/hadoop/src/test/java/org/apache/carbondata/hadoop/test/util/StoreCreator.java
index 8eb9a77..1fc0508 100644
--- a/hadoop/src/test/java/org/apache/carbondata/hadoop/test/util/StoreCreator.java
+++ b/hadoop/src/test/java/org/apache/carbondata/hadoop/test/util/StoreCreator.java
@@ -393,7 +393,6 @@ public class StoreCreator {
     CarbonProperties.getInstance().addProperty("carbon.is.fullyfilled.bits", "true");
     CarbonProperties.getInstance().addProperty("is.int.based.indexer", "true");
     CarbonProperties.getInstance().addProperty("aggregate.columnar.keyblock", "true");
-    CarbonProperties.getInstance().addProperty("high.cardinality.value", "100000");
     CarbonProperties.getInstance().addProperty("is.compressed.keyblock", "false");
     CarbonProperties.getInstance().addProperty("carbon.leaf.node.size", "120000");
 

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/presto/src/test/scala/org/apache/carbondata/presto/util/CarbonDataStoreCreator.scala
----------------------------------------------------------------------
diff --git a/integration/presto/src/test/scala/org/apache/carbondata/presto/util/CarbonDataStoreCreator.scala b/integration/presto/src/test/scala/org/apache/carbondata/presto/util/CarbonDataStoreCreator.scala
index 1bc9812..baf02fd 100644
--- a/integration/presto/src/test/scala/org/apache/carbondata/presto/util/CarbonDataStoreCreator.scala
+++ b/integration/presto/src/test/scala/org/apache/carbondata/presto/util/CarbonDataStoreCreator.scala
@@ -104,7 +104,7 @@ object CarbonDataStoreCreator {
       loadModel.setLoadMetadataDetails(new ArrayList[LoadMetadataDetails]())
       loadModel.setTablePath(absoluteTableIdentifier.getTablePath)
       CarbonProperties.getInstance
-        .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING, "true")
+        .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE, "true")
 
       loadModel.setDefaultTimestampFormat(
         CarbonProperties.getInstance.getProperty(
@@ -459,8 +459,6 @@ object CarbonDataStoreCreator {
     CarbonProperties.getInstance.addProperty("is.int.based.indexer", "true")
     CarbonProperties.getInstance
       .addProperty("aggregate.columnar.keyblock", "true")
-    CarbonProperties.getInstance
-      .addProperty("high.cardinality.value", "100000")
     CarbonProperties.getInstance.addProperty("is.compressed.keyblock", "false")
     CarbonProperties.getInstance.addProperty("carbon.leaf.node.size", "120000")
     CarbonProperties.getInstance

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery1TestCase.scala
----------------------------------------------------------------------
diff --git a/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery1TestCase.scala b/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery1TestCase.scala
index e213e49..764a73f 100644
--- a/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery1TestCase.scala
+++ b/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery1TestCase.scala
@@ -1043,7 +1043,6 @@ test("OffHeapQuery-001-TC_108", Include) {
 
   val prop = CarbonProperties.getInstance()
   val p1 = prop.getProperty("enable.unsafe.in.query.processing", CarbonCommonConstants.ENABLE_UNSAFE_IN_QUERY_EXECUTION_DEFAULTVALUE)
-  val p2 = prop.getProperty("use.offheap.in.query.processing", CarbonCommonConstants.USE_OFFHEAP_IN_QUERY_PROCSSING_DEFAULT)
 
   override protected def beforeAll() {
     // Adding new properties
@@ -1054,7 +1053,6 @@ test("OffHeapQuery-001-TC_108", Include) {
   override def afterAll: Unit = {
     //Reverting to old
     prop.addProperty("enable.unsafe.in.query.processing", p1)
-    prop.addProperty("use.offheap.in.query.processing", p2)
   }
        
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery2TestCase.scala
----------------------------------------------------------------------
diff --git a/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery2TestCase.scala b/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery2TestCase.scala
index 888070f..65d09e0 100644
--- a/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery2TestCase.scala
+++ b/integration/spark-common-cluster-test/src/test/scala/org/apache/carbondata/cluster/sdv/generated/OffheapQuery2TestCase.scala
@@ -1045,7 +1045,6 @@ class OffheapQuery2TestCase extends QueryTest with BeforeAndAfterAll {
 
   val prop = CarbonProperties.getInstance()
   val p1 = prop.getProperty("enable.unsafe.in.query.processing", CarbonCommonConstants.ENABLE_UNSAFE_IN_QUERY_EXECUTION_DEFAULTVALUE)
-  val p2 = prop.getProperty("use.offheap.in.query.processing", CarbonCommonConstants.USE_OFFHEAP_IN_QUERY_PROCSSING_DEFAULT)
 
   override protected def beforeAll() {
     // Adding new properties
@@ -1056,7 +1055,6 @@ class OffheapQuery2TestCase extends QueryTest with BeforeAndAfterAll {
   override def afterAll: Unit = {
     //Reverting to old
     prop.addProperty("enable.unsafe.in.query.processing", p1)
-    prop.addProperty("use.offheap.in.query.processing", p2)
   }
 
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark-common-test/src/test/scala/org/apache/carbondata/integration/spark/testsuite/aggquery/IntegerDataTypeTestCase.scala
----------------------------------------------------------------------
diff --git a/integration/spark-common-test/src/test/scala/org/apache/carbondata/integration/spark/testsuite/aggquery/IntegerDataTypeTestCase.scala b/integration/spark-common-test/src/test/scala/org/apache/carbondata/integration/spark/testsuite/aggquery/IntegerDataTypeTestCase.scala
index 4f9d09d..3eaf0e8 100644
--- a/integration/spark-common-test/src/test/scala/org/apache/carbondata/integration/spark/testsuite/aggquery/IntegerDataTypeTestCase.scala
+++ b/integration/spark-common-test/src/test/scala/org/apache/carbondata/integration/spark/testsuite/aggquery/IntegerDataTypeTestCase.scala
@@ -78,7 +78,7 @@ class IntegerDataTypeTestCase extends QueryTest with BeforeAndAfterAll {
 
   test("short int table boundary test, unsafe column page") {
     CarbonProperties.getInstance().addProperty(
-      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING, "true"
+      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE, "true"
     )
     sql(
       """
@@ -164,8 +164,8 @@ class IntegerDataTypeTestCase extends QueryTest with BeforeAndAfterAll {
   override def afterAll {
     sql("drop table if exists integertypetableAgg")
     CarbonProperties.getInstance().addProperty(
-      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING,
-      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING_DEFAULT
+      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE,
+      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_DEFAULT
     )
   }
 }

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/bigdecimal/TestNullAndEmptyFieldsUnsafe.scala
----------------------------------------------------------------------
diff --git a/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/bigdecimal/TestNullAndEmptyFieldsUnsafe.scala b/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/bigdecimal/TestNullAndEmptyFieldsUnsafe.scala
index 834ebc8..077a021 100644
--- a/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/bigdecimal/TestNullAndEmptyFieldsUnsafe.scala
+++ b/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/bigdecimal/TestNullAndEmptyFieldsUnsafe.scala
@@ -33,7 +33,7 @@ class TestNullAndEmptyFieldsUnsafe extends QueryTest with BeforeAndAfterAll {
     CarbonProperties.getInstance()
         .addProperty(CarbonCommonConstants.CARBON_TIMESTAMP_FORMAT,
           CarbonCommonConstants.CARBON_TIMESTAMP_DEFAULT_FORMAT)
-        .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING, "true")
+        .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE, "true")
     val csvFilePath = s"$resourcesPath/nullandnonparsableValue.csv"
     sql(
       "CREATE TABLE IF NOT EXISTS carbonTable (ID String, date Timestamp, country String, name " +
@@ -110,8 +110,8 @@ class TestNullAndEmptyFieldsUnsafe extends QueryTest with BeforeAndAfterAll {
     sql("drop table if exists hiveTable")
     CarbonProperties.getInstance()
         .addProperty(CarbonCommonConstants.CARBON_TIMESTAMP_FORMAT, "dd-MM-yyyy")
-        .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING,
-          CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING_DEFAULT)
+        .addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE,
+          CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_DEFAULT)
   }
 }
 

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/dataload/TestLoadDataWithHiveSyntaxUnsafe.scala
----------------------------------------------------------------------
diff --git a/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/dataload/TestLoadDataWithHiveSyntaxUnsafe.scala b/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/dataload/TestLoadDataWithHiveSyntaxUnsafe.scala
index 24637a6..599126b 100644
--- a/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/dataload/TestLoadDataWithHiveSyntaxUnsafe.scala
+++ b/integration/spark-common-test/src/test/scala/org/apache/carbondata/spark/testsuite/dataload/TestLoadDataWithHiveSyntaxUnsafe.scala
@@ -33,7 +33,7 @@ class TestLoadDataWithHiveSyntaxUnsafe extends QueryTest with BeforeAndAfterAll
 
   override def beforeAll {
     CarbonProperties.getInstance().addProperty(
-      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING,
+      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE,
       "true"
     )
     sql("drop table if exists escapechar1")
@@ -724,8 +724,8 @@ class TestLoadDataWithHiveSyntaxUnsafe extends QueryTest with BeforeAndAfterAll
     sql("drop table if exists decimal_varlength")
     sql("drop table if exists decimal_varlength_hive")
     CarbonProperties.getInstance().addProperty(
-      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING,
-      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING_DEFAULT
+      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE,
+      CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_DEFAULT
     )
   }
 }

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark-common/src/main/scala/org/apache/carbondata/spark/rdd/NewCarbonDataLoadRDD.scala
----------------------------------------------------------------------
diff --git a/integration/spark-common/src/main/scala/org/apache/carbondata/spark/rdd/NewCarbonDataLoadRDD.scala b/integration/spark-common/src/main/scala/org/apache/carbondata/spark/rdd/NewCarbonDataLoadRDD.scala
index 8ba2767..e607726 100644
--- a/integration/spark-common/src/main/scala/org/apache/carbondata/spark/rdd/NewCarbonDataLoadRDD.scala
+++ b/integration/spark-common/src/main/scala/org/apache/carbondata/spark/rdd/NewCarbonDataLoadRDD.scala
@@ -138,7 +138,6 @@ class SparkPartitionLoader(model: CarbonLoadModel,
     CarbonProperties.getInstance().addProperty("carbon.is.fullyfilled.bits", "true")
     CarbonProperties.getInstance().addProperty("is.int.based.indexer", "true")
     CarbonProperties.getInstance().addProperty("aggregate.columnar.keyblock", "true")
-    CarbonProperties.getInstance().addProperty("high.cardinality.value", "100000")
     CarbonProperties.getInstance().addProperty("is.compressed.keyblock", "false")
     CarbonProperties.getInstance().addProperty("carbon.leaf.node.size", "120000")
 

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark2/src/main/scala/org/apache/spark/sql/execution/command/management/CarbonAlterTableCompactionCommand.scala
----------------------------------------------------------------------
diff --git a/integration/spark2/src/main/scala/org/apache/spark/sql/execution/command/management/CarbonAlterTableCompactionCommand.scala b/integration/spark2/src/main/scala/org/apache/spark/sql/execution/command/management/CarbonAlterTableCompactionCommand.scala
index 2f4aa30..5183b02 100644
--- a/integration/spark2/src/main/scala/org/apache/spark/sql/execution/command/management/CarbonAlterTableCompactionCommand.scala
+++ b/integration/spark2/src/main/scala/org/apache/spark/sql/execution/command/management/CarbonAlterTableCompactionCommand.scala
@@ -118,9 +118,7 @@ case class CarbonAlterTableCompactionCommand(
       carbonLoadModel.setDatabaseName(table.getDatabaseName)
       carbonLoadModel.setTablePath(table.getTablePath)
 
-      var storeLocation = CarbonProperties.getInstance.getProperty(
-        CarbonCommonConstants.STORE_LOCATION_TEMP_PATH,
-        System.getProperty("java.io.tmpdir"))
+      var storeLocation = System.getProperty("java.io.tmpdir")
       storeLocation = storeLocation + "/carbonstore/" + System.nanoTime()
       // trigger event for compaction
       val alterTableCompactionPreEvent: AlterTableCompactionPreEvent =

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark2/src/main/scala/org/apache/spark/sql/test/Spark2TestQueryExecutor.scala
----------------------------------------------------------------------
diff --git a/integration/spark2/src/main/scala/org/apache/spark/sql/test/Spark2TestQueryExecutor.scala b/integration/spark2/src/main/scala/org/apache/spark/sql/test/Spark2TestQueryExecutor.scala
index 3fed15d..b341d6a 100644
--- a/integration/spark2/src/main/scala/org/apache/spark/sql/test/Spark2TestQueryExecutor.scala
+++ b/integration/spark2/src/main/scala/org/apache/spark/sql/test/Spark2TestQueryExecutor.scala
@@ -43,8 +43,6 @@ object Spark2TestQueryExecutor {
   private val LOGGER = LogServiceFactory.getLogService(this.getClass.getCanonicalName)
   LOGGER.info("use TestQueryExecutorImplV2")
   CarbonProperties.getInstance()
-    .addProperty(CarbonCommonConstants.STORE_LOCATION_TEMP_PATH,
-      System.getProperty("java.io.tmpdir"))
     .addProperty(CarbonCommonConstants.CARBON_BAD_RECORDS_ACTION, "FORCE")
 
 

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesBigFileTest.scala
----------------------------------------------------------------------
diff --git a/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesBigFileTest.scala b/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesBigFileTest.scala
index 53835fb..2090792 100644
--- a/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesBigFileTest.scala
+++ b/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesBigFileTest.scala
@@ -670,13 +670,13 @@ class BooleanDataTypesBigFileTest extends QueryTest with BeforeAndAfterEach with
 
   def initConf(): Unit = {
     CarbonProperties.getInstance().
-      addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING,
+      addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE,
         "true")
   }
 
   def defaultConf(): Unit = {
     CarbonProperties.getInstance().
-      addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING,
+      addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE,
         CarbonCommonConstants.ENABLE_DATA_LOADING_STATISTICS_DEFAULT)
   }
 }

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesLoadTest.scala
----------------------------------------------------------------------
diff --git a/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesLoadTest.scala b/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesLoadTest.scala
index fe11e43..c220f1c 100644
--- a/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesLoadTest.scala
+++ b/integration/spark2/src/test/scala/org/apache/carbondata/spark/testsuite/booleantype/BooleanDataTypesLoadTest.scala
@@ -774,13 +774,13 @@ class BooleanDataTypesLoadTest extends QueryTest with BeforeAndAfterEach with Be
 
   def initConf(): Unit ={
     CarbonProperties.getInstance().
-      addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING,
+      addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE,
         "true")
   }
 
   def defaultConf(): Unit ={
     CarbonProperties.getInstance().
-      addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE_LOADING,
+      addProperty(CarbonCommonConstants.ENABLE_UNSAFE_COLUMN_PAGE,
         CarbonCommonConstants.ENABLE_DATA_LOADING_STATISTICS_DEFAULT)
   }
 }

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/processing/src/test/java/org/apache/carbondata/processing/StoreCreator.java
----------------------------------------------------------------------
diff --git a/processing/src/test/java/org/apache/carbondata/processing/StoreCreator.java b/processing/src/test/java/org/apache/carbondata/processing/StoreCreator.java
index f594585..e79f003 100644
--- a/processing/src/test/java/org/apache/carbondata/processing/StoreCreator.java
+++ b/processing/src/test/java/org/apache/carbondata/processing/StoreCreator.java
@@ -366,7 +366,6 @@ public class StoreCreator {
     CarbonProperties.getInstance().addProperty("carbon.is.fullyfilled.bits", "true");
     CarbonProperties.getInstance().addProperty("is.int.based.indexer", "true");
     CarbonProperties.getInstance().addProperty("aggregate.columnar.keyblock", "true");
-    CarbonProperties.getInstance().addProperty("high.cardinality.value", "100000");
     CarbonProperties.getInstance().addProperty("is.compressed.keyblock", "false");
     CarbonProperties.getInstance().addProperty("carbon.leaf.node.size", "120000");
diff --git a/core/src/main/java/org/apache/carbondata/core/constants/CarbonCommonConstants.java b/core/src/main/java/org/apache/carbondata/core/constants/CarbonCommonConstants.java
index af3ed99..b0e3536 100644
--- a/core/src/main/java/org/apache/carbondata/core/constants/CarbonCommonConstants.java
+++ b/core/src/main/java/org/apache/carbondata/core/constants/CarbonCommonConstants.java
@@ -280,15 +280,6 @@ public final class CarbonCommonConstants {
    */
   public static final String MEASUREMETADATA_FILE_EXT = ".msrmetadata";
   /**
-   * GRAPH_ROWSET_SIZE
-   */
-  @CarbonProperty
-  public static final String GRAPH_ROWSET_SIZE = "carbon.graph.rowset.size";
-  /**
-   * GRAPH_ROWSET_SIZE_DEFAULT
-   */
-  public static final String GRAPH_ROWSET_SIZE_DEFAULT = "500";
-  /**
    * Comment for <code>TYPE_MYSQL</code>
    */
   public static final String TYPE_MYSQL = "MYSQL";
@@ -331,15 +322,6 @@ public final class CarbonCommonConstants {
   @CarbonProperty
   public static final String SORT_FILE_BUFFER_SIZE = "carbon.sort.file.buffer.size";
   /**
-   * no.of records after which counter to be printed
-   */
-  @CarbonProperty
-  public static final String DATA_LOAD_LOG_COUNTER = "carbon.load.log.counter";
-  /**
-   * DATA_LOAD_LOG_COUNTER_DEFAULT_COUNTER
-   */
-  public static final String DATA_LOAD_LOG_COUNTER_DEFAULT_COUNTER = "500000";
-  /**
    * SORT_FILE_WRITE_BUFFER_SIZE
    */
   @CarbonProperty
@@ -482,11 +464,6 @@ public final class CarbonCommonConstants {
   @CarbonProperty
   public static final String STORE_LOCATION_HDFS = "carbon.storelocation.hdfs";
   /**
-   * STORE_LOCATION_TEMP_PATH
-   */
-  @CarbonProperty
-  public static final String STORE_LOCATION_TEMP_PATH = "carbon.tempstore.location";
-  /**
    * IS_COLUMNAR_STORAGE_DEFAULTVALUE
    */
   public static final String IS_COLUMNAR_STORAGE_DEFAULTVALUE = "true";
@@ -695,11 +672,6 @@ public final class CarbonCommonConstants {
    */
   public static final String POSITION_ID = "positionId";
   /**
-   * max driver lru cache size upto which lru cache will be loaded in memory
-   */
-  @CarbonProperty
-  public static final String CARBON_MAX_LEVEL_CACHE_SIZE = "carbon.max.level.cache.size";
-  /**
    * max executor lru cache size upto which lru cache will be loaded in memory
    */
   @CarbonProperty
@@ -1168,14 +1140,14 @@ public final class CarbonCommonConstants {
 
 
   /**
-   * to enable unsafe column page in write step
+   * to enable unsafe column page
    */
-  public static final String ENABLE_UNSAFE_COLUMN_PAGE_LOADING = "enable.unsafe.columnpage";
+  public static final String ENABLE_UNSAFE_COLUMN_PAGE = "enable.unsafe.columnpage";
 
   /**
    * default value of ENABLE_UNSAFE_COLUMN_PAGE_LOADING
    */
-  public static final String ENABLE_UNSAFE_COLUMN_PAGE_LOADING_DEFAULT = "false";
+  public static final String ENABLE_UNSAFE_COLUMN_PAGE_DEFAULT = "true";
 
   /**
    * to enable offheap sort
@@ -1186,7 +1158,7 @@ public final class CarbonCommonConstants {
   /**
    * to enable offheap sort
    */
-  public static final String ENABLE_UNSAFE_SORT_DEFAULT = "false";
+  public static final String ENABLE_UNSAFE_SORT_DEFAULT = "true";
 
   /**
    * to enable offheap sort
@@ -1268,11 +1240,6 @@ public final class CarbonCommonConstants {
   public static final String IS_DRIVER_INSTANCE = "is.driver.instance";
 
   /**
-   * maximum length of column
-   */
-  public static final int DEFAULT_COLUMN_LENGTH = 100000;
-
-  /**
    * property for enabling unsafe based query processing
    */
   @CarbonProperty
@@ -1281,18 +1248,7 @@ public final class CarbonCommonConstants {
   /**
    * default property of unsafe processing
    */
-  public static final String ENABLE_UNSAFE_IN_QUERY_EXECUTION_DEFAULTVALUE = "false";
-
-  /**
-   * property for offheap based processing
-   */
-  @CarbonProperty
-  public static final String USE_OFFHEAP_IN_QUERY_PROCSSING = "use.offheap.in.query.processing";
-
-  /**
-   * default value of offheap based processing
-   */
-  public static final String USE_OFFHEAP_IN_QUERY_PROCSSING_DEFAULT = "true";
+  public static final String ENABLE_UNSAFE_IN_QUERY_EXECUTION_DEFAULTVALUE = "true";
 
   /**
    * whether to prefetch data while loading.

http://git-wip-us.apache.org/repos/asf/carbondata/blob/be600bc9/core/src/main/java/org/apache/carbondata/core/datastore/page/ColumnPage.java
----------------------------------------------------------------------
@@ -1168,14 +1140,14 @@ public final class CarbonCommonConstants {
 
   /**
-   * default value of ENABLE_UNSAFE_COLUMN_PAGE_LOADING
+   * default value of ENABLE_UNSAFE_COLUMN_PAGE
    */